# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Api(pulumi.CustomResource):
    api_id: pulumi.Output[str]
    """
    The ID of the api of api gateway.
    """
    auth_type: pulumi.Output[str]
    """
    The authorization Type including APP and ANONYMOUS. Defaults to null.
    """
    constant_parameters: pulumi.Output[list]
    """
    constant_parameters defines the constant parameters of the api.
    
      * `description` (`str`) - The description of Constant parameter.
      * `in` (`str`) - System parameter location; values: 'HEAD' and 'QUERY'.
      * `name` (`str`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
      * `value` (`str`) - Constant parameter value.
    """
    description: pulumi.Output[str]
    """
    The description of Constant parameter.
    """
    fc_service_config: pulumi.Output[dict]
    """
    fc_service_config defines the config when service_type selected 'FunctionCompute'.
    
      * `arnRole` (`str`) - RAM role arn attached to the Function Compute service. This governs both who / what can invoke your Function, as well as what resources our Function has access to. See [User Permissions](https://www.alibabacloud.com/help/doc-detail/52885.htm) for more details.
      * `functionName` (`str`) - The function name of function compute service.
      * `region` (`str`) - The region that the function compute service belongs to.
      * `serviceName` (`str`) - The service name of function compute service.
      * `timeout` (`float`) - Backend service time-out time; unit: millisecond.
    """
    group_id: pulumi.Output[str]
    """
    The api gateway that the api belongs to. Defaults to null.
    """
    http_service_config: pulumi.Output[dict]
    """
    http_service_config defines the config when service_type selected 'HTTP'.
    
      * `address` (`str`) - The address of backend service.
      * `aoneName` (`str`)
      * `method` (`str`) - The http method of backend service.
      * `path` (`str`) - The path of backend service.
      * `timeout` (`float`) - Backend service time-out time; unit: millisecond.
    """
    http_vpc_service_config: pulumi.Output[dict]
    """
    http_vpc_service_config defines the config when service_type selected 'HTTP-VPC'.
    
      * `aoneName` (`str`)
      * `method` (`str`) - The http method of backend service.
      * `name` (`str`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
      * `path` (`str`) - The path of backend service.
      * `timeout` (`float`) - Backend service time-out time; unit: millisecond.
    """
    mock_service_config: pulumi.Output[dict]
    """
    http_service_config defines the config when service_type selected 'MOCK'.
    
      * `aoneName` (`str`)
      * `result` (`str`) - The result of the mock service.
    """
    name: pulumi.Output[str]
    """
    System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
    """
    request_config: pulumi.Output[dict]
    """
    Request_config defines how users can send requests to your API.
    
      * `bodyFormat` (`str`) - The body format of the api, which support the values of 'STREAM' and 'FORM'
      * `method` (`str`) - The http method of backend service.
      * `mode` (`str`) - The mode of the parameters between request parameters and service parameters, which support the values of 'MAPPING' and 'PASSTHROUGH'
      * `path` (`str`) - The path of backend service.
      * `protocol` (`str`) - The protocol of api which supports values of 'HTTP','HTTPS' or 'HTTP,HTTPS'
    """
    request_parameters: pulumi.Output[list]
    """
    request_parameters defines the request parameters of the api.
    
      * `defaultValue` (`str`) - The default value of the parameter.
      * `description` (`str`) - The description of Constant parameter.
      * `in` (`str`) - System parameter location; values: 'HEAD' and 'QUERY'.
      * `inService` (`str`) - Backend service's parameter location; values: BODY, HEAD, QUERY, and PATH.
      * `name` (`str`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
      * `nameService` (`str`) - Backend service's parameter name.
      * `required` (`str`) - Parameter required or not; values: REQUIRED and OPTIONAL.
      * `type` (`str`) - Parameter type which supports values of 'STRING','INT','BOOLEAN','LONG',"FLOAT" and "DOUBLE"
    """
    service_type: pulumi.Output[str]
    """
    The type of backend service. Type including HTTP,VPC and MOCK. Defaults to null.
    """
    stage_names: pulumi.Output[list]
    """
    Stages that the api need to be deployed. Valid value: RELEASE | PRE | TEST.
    """
    system_parameters: pulumi.Output[list]
    """
    system_parameters defines the system parameters of the api.
    
      * `in` (`str`) - System parameter location; values: 'HEAD' and 'QUERY'.
      * `name` (`str`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
      * `nameService` (`str`) - Backend service's parameter name.
    """
    def __init__(__self__, resource_name, opts=None, auth_type=None, constant_parameters=None, description=None, fc_service_config=None, group_id=None, http_service_config=None, http_vpc_service_config=None, mock_service_config=None, name=None, request_config=None, request_parameters=None, service_type=None, stage_names=None, system_parameters=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Api resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_type: The authorization Type including APP and ANONYMOUS. Defaults to null.
        :param pulumi.Input[list] constant_parameters: constant_parameters defines the constant parameters of the api.
        :param pulumi.Input[str] description: The description of Constant parameter.
        :param pulumi.Input[dict] fc_service_config: fc_service_config defines the config when service_type selected 'FunctionCompute'.
        :param pulumi.Input[str] group_id: The api gateway that the api belongs to. Defaults to null.
        :param pulumi.Input[dict] http_service_config: http_service_config defines the config when service_type selected 'HTTP'.
        :param pulumi.Input[dict] http_vpc_service_config: http_vpc_service_config defines the config when service_type selected 'HTTP-VPC'.
        :param pulumi.Input[dict] mock_service_config: http_service_config defines the config when service_type selected 'MOCK'.
        :param pulumi.Input[str] name: System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
        :param pulumi.Input[dict] request_config: Request_config defines how users can send requests to your API.
        :param pulumi.Input[list] request_parameters: request_parameters defines the request parameters of the api.
        :param pulumi.Input[str] service_type: The type of backend service. Type including HTTP,VPC and MOCK. Defaults to null.
        :param pulumi.Input[list] stage_names: Stages that the api need to be deployed. Valid value: RELEASE | PRE | TEST.
        :param pulumi.Input[list] system_parameters: system_parameters defines the system parameters of the api.
        
        The **constant_parameters** object supports the following:
        
          * `description` (`pulumi.Input[str]`) - The description of Constant parameter.
          * `in` (`pulumi.Input[str]`) - System parameter location; values: 'HEAD' and 'QUERY'.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `value` (`pulumi.Input[str]`) - Constant parameter value.
        
        The **fc_service_config** object supports the following:
        
          * `arnRole` (`pulumi.Input[str]`) - RAM role arn attached to the Function Compute service. This governs both who / what can invoke your Function, as well as what resources our Function has access to. See [User Permissions](https://www.alibabacloud.com/help/doc-detail/52885.htm) for more details.
          * `functionName` (`pulumi.Input[str]`) - The function name of function compute service.
          * `region` (`pulumi.Input[str]`) - The region that the function compute service belongs to.
          * `serviceName` (`pulumi.Input[str]`) - The service name of function compute service.
          * `timeout` (`pulumi.Input[float]`) - Backend service time-out time; unit: millisecond.
        
        The **http_service_config** object supports the following:
        
          * `address` (`pulumi.Input[str]`) - The address of backend service.
          * `aoneName` (`pulumi.Input[str]`)
          * `method` (`pulumi.Input[str]`) - The http method of backend service.
          * `path` (`pulumi.Input[str]`) - The path of backend service.
          * `timeout` (`pulumi.Input[float]`) - Backend service time-out time; unit: millisecond.
        
        The **http_vpc_service_config** object supports the following:
        
          * `aoneName` (`pulumi.Input[str]`)
          * `method` (`pulumi.Input[str]`) - The http method of backend service.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `path` (`pulumi.Input[str]`) - The path of backend service.
          * `timeout` (`pulumi.Input[float]`) - Backend service time-out time; unit: millisecond.
        
        The **mock_service_config** object supports the following:
        
          * `aoneName` (`pulumi.Input[str]`)
          * `result` (`pulumi.Input[str]`) - The result of the mock service.
        
        The **request_config** object supports the following:
        
          * `bodyFormat` (`pulumi.Input[str]`) - The body format of the api, which support the values of 'STREAM' and 'FORM'
          * `method` (`pulumi.Input[str]`) - The http method of backend service.
          * `mode` (`pulumi.Input[str]`) - The mode of the parameters between request parameters and service parameters, which support the values of 'MAPPING' and 'PASSTHROUGH'
          * `path` (`pulumi.Input[str]`) - The path of backend service.
          * `protocol` (`pulumi.Input[str]`) - The protocol of api which supports values of 'HTTP','HTTPS' or 'HTTP,HTTPS'
        
        The **request_parameters** object supports the following:
        
          * `defaultValue` (`pulumi.Input[str]`) - The default value of the parameter.
          * `description` (`pulumi.Input[str]`) - The description of Constant parameter.
          * `in` (`pulumi.Input[str]`) - System parameter location; values: 'HEAD' and 'QUERY'.
          * `inService` (`pulumi.Input[str]`) - Backend service's parameter location; values: BODY, HEAD, QUERY, and PATH.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `nameService` (`pulumi.Input[str]`) - Backend service's parameter name.
          * `required` (`pulumi.Input[str]`) - Parameter required or not; values: REQUIRED and OPTIONAL.
          * `type` (`pulumi.Input[str]`) - Parameter type which supports values of 'STRING','INT','BOOLEAN','LONG',"FLOAT" and "DOUBLE"
        
        The **system_parameters** object supports the following:
        
          * `in` (`pulumi.Input[str]`) - System parameter location; values: 'HEAD' and 'QUERY'.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `nameService` (`pulumi.Input[str]`) - Backend service's parameter name.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/api_gateway_api.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if auth_type is None:
                raise TypeError("Missing required property 'auth_type'")
            __props__['auth_type'] = auth_type
            __props__['constant_parameters'] = constant_parameters
            if description is None:
                raise TypeError("Missing required property 'description'")
            __props__['description'] = description
            __props__['fc_service_config'] = fc_service_config
            if group_id is None:
                raise TypeError("Missing required property 'group_id'")
            __props__['group_id'] = group_id
            __props__['http_service_config'] = http_service_config
            __props__['http_vpc_service_config'] = http_vpc_service_config
            __props__['mock_service_config'] = mock_service_config
            __props__['name'] = name
            if request_config is None:
                raise TypeError("Missing required property 'request_config'")
            __props__['request_config'] = request_config
            __props__['request_parameters'] = request_parameters
            if service_type is None:
                raise TypeError("Missing required property 'service_type'")
            __props__['service_type'] = service_type
            __props__['stage_names'] = stage_names
            __props__['system_parameters'] = system_parameters
            __props__['api_id'] = None
        super(Api, __self__).__init__(
            'alicloud:apigateway/api:Api',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, api_id=None, auth_type=None, constant_parameters=None, description=None, fc_service_config=None, group_id=None, http_service_config=None, http_vpc_service_config=None, mock_service_config=None, name=None, request_config=None, request_parameters=None, service_type=None, stage_names=None, system_parameters=None):
        """
        Get an existing Api resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_id: The ID of the api of api gateway.
        :param pulumi.Input[str] auth_type: The authorization Type including APP and ANONYMOUS. Defaults to null.
        :param pulumi.Input[list] constant_parameters: constant_parameters defines the constant parameters of the api.
        :param pulumi.Input[str] description: The description of Constant parameter.
        :param pulumi.Input[dict] fc_service_config: fc_service_config defines the config when service_type selected 'FunctionCompute'.
        :param pulumi.Input[str] group_id: The api gateway that the api belongs to. Defaults to null.
        :param pulumi.Input[dict] http_service_config: http_service_config defines the config when service_type selected 'HTTP'.
        :param pulumi.Input[dict] http_vpc_service_config: http_vpc_service_config defines the config when service_type selected 'HTTP-VPC'.
        :param pulumi.Input[dict] mock_service_config: http_service_config defines the config when service_type selected 'MOCK'.
        :param pulumi.Input[str] name: System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
        :param pulumi.Input[dict] request_config: Request_config defines how users can send requests to your API.
        :param pulumi.Input[list] request_parameters: request_parameters defines the request parameters of the api.
        :param pulumi.Input[str] service_type: The type of backend service. Type including HTTP,VPC and MOCK. Defaults to null.
        :param pulumi.Input[list] stage_names: Stages that the api need to be deployed. Valid value: RELEASE | PRE | TEST.
        :param pulumi.Input[list] system_parameters: system_parameters defines the system parameters of the api.
        
        The **constant_parameters** object supports the following:
        
          * `description` (`pulumi.Input[str]`) - The description of Constant parameter.
          * `in` (`pulumi.Input[str]`) - System parameter location; values: 'HEAD' and 'QUERY'.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `value` (`pulumi.Input[str]`) - Constant parameter value.
        
        The **fc_service_config** object supports the following:
        
          * `arnRole` (`pulumi.Input[str]`) - RAM role arn attached to the Function Compute service. This governs both who / what can invoke your Function, as well as what resources our Function has access to. See [User Permissions](https://www.alibabacloud.com/help/doc-detail/52885.htm) for more details.
          * `functionName` (`pulumi.Input[str]`) - The function name of function compute service.
          * `region` (`pulumi.Input[str]`) - The region that the function compute service belongs to.
          * `serviceName` (`pulumi.Input[str]`) - The service name of function compute service.
          * `timeout` (`pulumi.Input[float]`) - Backend service time-out time; unit: millisecond.
        
        The **http_service_config** object supports the following:
        
          * `address` (`pulumi.Input[str]`) - The address of backend service.
          * `aoneName` (`pulumi.Input[str]`)
          * `method` (`pulumi.Input[str]`) - The http method of backend service.
          * `path` (`pulumi.Input[str]`) - The path of backend service.
          * `timeout` (`pulumi.Input[float]`) - Backend service time-out time; unit: millisecond.
        
        The **http_vpc_service_config** object supports the following:
        
          * `aoneName` (`pulumi.Input[str]`)
          * `method` (`pulumi.Input[str]`) - The http method of backend service.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `path` (`pulumi.Input[str]`) - The path of backend service.
          * `timeout` (`pulumi.Input[float]`) - Backend service time-out time; unit: millisecond.
        
        The **mock_service_config** object supports the following:
        
          * `aoneName` (`pulumi.Input[str]`)
          * `result` (`pulumi.Input[str]`) - The result of the mock service.
        
        The **request_config** object supports the following:
        
          * `bodyFormat` (`pulumi.Input[str]`) - The body format of the api, which support the values of 'STREAM' and 'FORM'
          * `method` (`pulumi.Input[str]`) - The http method of backend service.
          * `mode` (`pulumi.Input[str]`) - The mode of the parameters between request parameters and service parameters, which support the values of 'MAPPING' and 'PASSTHROUGH'
          * `path` (`pulumi.Input[str]`) - The path of backend service.
          * `protocol` (`pulumi.Input[str]`) - The protocol of api which supports values of 'HTTP','HTTPS' or 'HTTP,HTTPS'
        
        The **request_parameters** object supports the following:
        
          * `defaultValue` (`pulumi.Input[str]`) - The default value of the parameter.
          * `description` (`pulumi.Input[str]`) - The description of Constant parameter.
          * `in` (`pulumi.Input[str]`) - System parameter location; values: 'HEAD' and 'QUERY'.
          * `inService` (`pulumi.Input[str]`) - Backend service's parameter location; values: BODY, HEAD, QUERY, and PATH.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `nameService` (`pulumi.Input[str]`) - Backend service's parameter name.
          * `required` (`pulumi.Input[str]`) - Parameter required or not; values: REQUIRED and OPTIONAL.
          * `type` (`pulumi.Input[str]`) - Parameter type which supports values of 'STRING','INT','BOOLEAN','LONG',"FLOAT" and "DOUBLE"
        
        The **system_parameters** object supports the following:
        
          * `in` (`pulumi.Input[str]`) - System parameter location; values: 'HEAD' and 'QUERY'.
          * `name` (`pulumi.Input[str]`) - System parameter name which supports values including in [system parameter list](https://www.alibabacloud.com/help/doc-detail/43677.html)
          * `nameService` (`pulumi.Input[str]`) - Backend service's parameter name.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/api_gateway_api.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["api_id"] = api_id
        __props__["auth_type"] = auth_type
        __props__["constant_parameters"] = constant_parameters
        __props__["description"] = description
        __props__["fc_service_config"] = fc_service_config
        __props__["group_id"] = group_id
        __props__["http_service_config"] = http_service_config
        __props__["http_vpc_service_config"] = http_vpc_service_config
        __props__["mock_service_config"] = mock_service_config
        __props__["name"] = name
        __props__["request_config"] = request_config
        __props__["request_parameters"] = request_parameters
        __props__["service_type"] = service_type
        __props__["stage_names"] = stage_names
        __props__["system_parameters"] = system_parameters
        return Api(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ReadOnlyInstance(pulumi.CustomResource):
    connection_string: pulumi.Output[str]
    """
    RDS database connection string.
    """
    engine: pulumi.Output[str]
    """
    Database type.
    """
    engine_version: pulumi.Output[str]
    """
    Database version. Value options can refer to the latest docs [CreateDBInstance](https://www.alibabacloud.com/help/doc-detail/26228.htm) `EngineVersion`.
    """
    instance_name: pulumi.Output[str]
    """
    The name of DB instance. It a string of 2 to 256 characters.
    """
    instance_storage: pulumi.Output[float]
    """
    User-defined DB instance storage space. Value range: [5, 2000] for MySQL/SQL Server HA dual node edition. Increase progressively at a rate of 5 GB. For details, see [Instance type table](https://www.alibabacloud.com/help/doc-detail/26312.htm).
    """
    instance_type: pulumi.Output[str]
    """
    DB Instance type. For details, see [Instance type table](https://www.alibabacloud.com/help/doc-detail/26312.htm).
    """
    master_db_instance_id: pulumi.Output[str]
    """
    ID of the master instance.
    """
    parameters: pulumi.Output[list]
    """
    Set of parameters needs to be set after DB instance was launched. Available parameters can refer to the latest docs [View database parameter templates](https://www.alibabacloud.com/help/doc-detail/26284.htm).
    
      * `name` (`str`)
      * `value` (`str`)
    """
    port: pulumi.Output[str]
    """
    RDS database connection port.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
    - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
    """
    vswitch_id: pulumi.Output[str]
    """
    The virtual switch ID to launch DB instances in one VPC.
    """
    zone_id: pulumi.Output[str]
    """
    The Zone to launch the DB instance.
    """
    def __init__(__self__, resource_name, opts=None, engine_version=None, instance_name=None, instance_storage=None, instance_type=None, master_db_instance_id=None, parameters=None, tags=None, vswitch_id=None, zone_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an RDS readonly instance resource. 
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] engine_version: Database version. Value options can refer to the latest docs [CreateDBInstance](https://www.alibabacloud.com/help/doc-detail/26228.htm) `EngineVersion`.
        :param pulumi.Input[str] instance_name: The name of DB instance. It a string of 2 to 256 characters.
        :param pulumi.Input[float] instance_storage: User-defined DB instance storage space. Value range: [5, 2000] for MySQL/SQL Server HA dual node edition. Increase progressively at a rate of 5 GB. For details, see [Instance type table](https://www.alibabacloud.com/help/doc-detail/26312.htm).
        :param pulumi.Input[str] instance_type: DB Instance type. For details, see [Instance type table](https://www.alibabacloud.com/help/doc-detail/26312.htm).
        :param pulumi.Input[str] master_db_instance_id: ID of the master instance.
        :param pulumi.Input[list] parameters: Set of parameters needs to be set after DB instance was launched. Available parameters can refer to the latest docs [View database parameter templates](https://www.alibabacloud.com/help/doc-detail/26284.htm).
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
               - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
               - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        :param pulumi.Input[str] vswitch_id: The virtual switch ID to launch DB instances in one VPC.
        :param pulumi.Input[str] zone_id: The Zone to launch the DB instance.
        
        The **parameters** object supports the following:
        
          * `name` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/db_readonly_instance.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if engine_version is None:
                raise TypeError("Missing required property 'engine_version'")
            __props__['engine_version'] = engine_version
            __props__['instance_name'] = instance_name
            if instance_storage is None:
                raise TypeError("Missing required property 'instance_storage'")
            __props__['instance_storage'] = instance_storage
            if instance_type is None:
                raise TypeError("Missing required property 'instance_type'")
            __props__['instance_type'] = instance_type
            if master_db_instance_id is None:
                raise TypeError("Missing required property 'master_db_instance_id'")
            __props__['master_db_instance_id'] = master_db_instance_id
            __props__['parameters'] = parameters
            __props__['tags'] = tags
            __props__['vswitch_id'] = vswitch_id
            __props__['zone_id'] = zone_id
            __props__['connection_string'] = None
            __props__['engine'] = None
            __props__['port'] = None
        super(ReadOnlyInstance, __self__).__init__(
            'alicloud:rds/readOnlyInstance:ReadOnlyInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, connection_string=None, engine=None, engine_version=None, instance_name=None, instance_storage=None, instance_type=None, master_db_instance_id=None, parameters=None, port=None, tags=None, vswitch_id=None, zone_id=None):
        """
        Get an existing ReadOnlyInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connection_string: RDS database connection string.
        :param pulumi.Input[str] engine: Database type.
        :param pulumi.Input[str] engine_version: Database version. Value options can refer to the latest docs [CreateDBInstance](https://www.alibabacloud.com/help/doc-detail/26228.htm) `EngineVersion`.
        :param pulumi.Input[str] instance_name: The name of DB instance. It a string of 2 to 256 characters.
        :param pulumi.Input[float] instance_storage: User-defined DB instance storage space. Value range: [5, 2000] for MySQL/SQL Server HA dual node edition. Increase progressively at a rate of 5 GB. For details, see [Instance type table](https://www.alibabacloud.com/help/doc-detail/26312.htm).
        :param pulumi.Input[str] instance_type: DB Instance type. For details, see [Instance type table](https://www.alibabacloud.com/help/doc-detail/26312.htm).
        :param pulumi.Input[str] master_db_instance_id: ID of the master instance.
        :param pulumi.Input[list] parameters: Set of parameters needs to be set after DB instance was launched. Available parameters can refer to the latest docs [View database parameter templates](https://www.alibabacloud.com/help/doc-detail/26284.htm).
        :param pulumi.Input[str] port: RDS database connection port.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
               - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
               - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        :param pulumi.Input[str] vswitch_id: The virtual switch ID to launch DB instances in one VPC.
        :param pulumi.Input[str] zone_id: The Zone to launch the DB instance.
        
        The **parameters** object supports the following:
        
          * `name` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/db_readonly_instance.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["connection_string"] = connection_string
        __props__["engine"] = engine
        __props__["engine_version"] = engine_version
        __props__["instance_name"] = instance_name
        __props__["instance_storage"] = instance_storage
        __props__["instance_type"] = instance_type
        __props__["master_db_instance_id"] = master_db_instance_id
        __props__["parameters"] = parameters
        __props__["port"] = port
        __props__["tags"] = tags
        __props__["vswitch_id"] = vswitch_id
        __props__["zone_id"] = zone_id
        return ReadOnlyInstance(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetDBAuditInstanceResult:
    """
    A collection of values returned by getDBAuditInstance.
    """
    def __init__(__self__, description_regex=None, descriptions=None, ids=None, instances=None, output_file=None, tags=None, id=None):
        if description_regex and not isinstance(description_regex, str):
            raise TypeError("Expected argument 'description_regex' to be a str")
        __self__.description_regex = description_regex
        if descriptions and not isinstance(descriptions, list):
            raise TypeError("Expected argument 'descriptions' to be a list")
        __self__.descriptions = descriptions
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        __self__.ids = ids
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        __self__.instances = instances
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        __self__.output_file = output_file
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetDBAuditInstanceResult(GetDBAuditInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDBAuditInstanceResult(
            description_regex=self.description_regex,
            descriptions=self.descriptions,
            ids=self.ids,
            instances=self.instances,
            output_file=self.output_file,
            tags=self.tags,
            id=self.id)

def get_db_audit_instance(description_regex=None,ids=None,output_file=None,tags=None,opts=None):
    """
    Use this data source to access information about an existing resource.
    
    """
    __args__ = dict()

    __args__['descriptionRegex'] = description_regex
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:yundun/getDBAuditInstance:getDBAuditInstance', __args__, opts=opts).value

    return AwaitableGetDBAuditInstanceResult(
        description_regex=__ret__.get('descriptionRegex'),
        descriptions=__ret__.get('descriptions'),
        ids=__ret__.get('ids'),
        instances=__ret__.get('instances'),
        output_file=__ret__.get('outputFile'),
        tags=__ret__.get('tags'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Topic(pulumi.CustomResource):
    compact_topic: pulumi.Output[bool]
    """
    Whether the topic is compactTopic or not. Compact topic must be a localTopic.
    """
    instance_id: pulumi.Output[str]
    """
    InstanceId of your Kafka resource, the topic will create in this instance.
    """
    local_topic: pulumi.Output[bool]
    """
    Whether the topic is localTopic or not.
    """
    partition_num: pulumi.Output[float]
    """
    The number of partitions of the topic. The number should between 1 and 48.
    """
    remark: pulumi.Output[str]
    """
    This attribute is a concise description of topic. The length cannot exceed 64.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    topic: pulumi.Output[str]
    """
    Name of the topic. Two topics on a single instance cannot have the same name. The length cannot exceed 64 characters.
    """
    def __init__(__self__, resource_name, opts=None, compact_topic=None, instance_id=None, local_topic=None, partition_num=None, remark=None, tags=None, topic=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an ALIKAFKA topic resource.
        
        > **NOTE:** Available in 1.56.0+
        
        > **NOTE:**  Only the following regions support create alikafka topic.
        [`cn-hangzhou`,`cn-beijing`,`cn-shenzhen`,`cn-shanghai`,`cn-qingdao`,`cn-hongkong`,`cn-huhehaote`,`cn-zhangjiakou`,`ap-southeast-1`,`ap-south-1`,`ap-southeast-5`]
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] compact_topic: Whether the topic is compactTopic or not. Compact topic must be a localTopic.
        :param pulumi.Input[str] instance_id: InstanceId of your Kafka resource, the topic will create in this instance.
        :param pulumi.Input[bool] local_topic: Whether the topic is localTopic or not.
        :param pulumi.Input[float] partition_num: The number of partitions of the topic. The number should between 1 and 48.
        :param pulumi.Input[str] remark: This attribute is a concise description of topic. The length cannot exceed 64.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] topic: Name of the topic. Two topics on a single instance cannot have the same name. The length cannot exceed 64 characters.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/alikafka_topic.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['compact_topic'] = compact_topic
            if instance_id is None:
                raise TypeError("Missing required property 'instance_id'")
            __props__['instance_id'] = instance_id
            __props__['local_topic'] = local_topic
            __props__['partition_num'] = partition_num
            if remark is None:
                raise TypeError("Missing required property 'remark'")
            __props__['remark'] = remark
            __props__['tags'] = tags
            if topic is None:
                raise TypeError("Missing required property 'topic'")
            __props__['topic'] = topic
        super(Topic, __self__).__init__(
            'alicloud:alikafka/topic:Topic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, compact_topic=None, instance_id=None, local_topic=None, partition_num=None, remark=None, tags=None, topic=None):
        """
        Get an existing Topic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] compact_topic: Whether the topic is compactTopic or not. Compact topic must be a localTopic.
        :param pulumi.Input[str] instance_id: InstanceId of your Kafka resource, the topic will create in this instance.
        :param pulumi.Input[bool] local_topic: Whether the topic is localTopic or not.
        :param pulumi.Input[float] partition_num: The number of partitions of the topic. The number should between 1 and 48.
        :param pulumi.Input[str] remark: This attribute is a concise description of topic. The length cannot exceed 64.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] topic: Name of the topic. Two topics on a single instance cannot have the same name. The length cannot exceed 64 characters.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/alikafka_topic.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["compact_topic"] = compact_topic
        __props__["instance_id"] = instance_id
        __props__["local_topic"] = local_topic
        __props__["partition_num"] = partition_num
        __props__["remark"] = remark
        __props__["tags"] = tags
        __props__["topic"] = topic
        return Topic(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ClientUser(pulumi.CustomResource):
    bandwidth: pulumi.Output[float]
    """
    The SAG APP bandwidth that the user can use. Unit: Kbit/s. Maximum value: 2000 Kbit/s.
    """
    client_ip: pulumi.Output[str]
    """
    The IP address of the SAG APP. If you specify this parameter, the current account always uses the specified IP address.Note The IP address must be in the private CIDR block of the SAG client.If you do not specify this parameter, the system automatically allocates an IP address from the private CIDR block of the SAG client. In this case, each re-connection uses a different IP address.
    """
    kms_encrypted_password: pulumi.Output[str]
    kms_encryption_context: pulumi.Output[dict]
    password: pulumi.Output[str]
    """
    The password used to log on to the SAG APP.Both the user name and the password must be specified. If you specify the user name, the password must be specified, too.
    """
    sag_id: pulumi.Output[str]
    """
    The ID of the SAG instance created for the SAG APP.
    """
    user_mail: pulumi.Output[str]
    """
    The email address of the user. The administrator uses this address to send the account information for logging on to the APP to the user.
    """
    user_name: pulumi.Output[str]
    """
    The user name. User names in the same SAG APP must be unique.Both the user name and the password must be specified. If you specify the user name, the password must be specified, too.
    """
    def __init__(__self__, resource_name, opts=None, bandwidth=None, client_ip=None, kms_encrypted_password=None, kms_encryption_context=None, password=None, sag_id=None, user_mail=None, user_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Sag ClientUser resource. This topic describes how to manage accounts as an administrator. After you configure the network, you can create multiple accounts and distribute them to end users so that clients can access Alibaba Cloud.
        
        For information about Sag ClientUser and how to use it, see [What is Sag ClientUser](https://www.alibabacloud.com/help/doc-detail/108326.htm).
        
        > **NOTE:** Available in 1.65.0+
        
        > **NOTE:** Only the following regions support. [`cn-shanghai`, `cn-shanghai-finance-1`, `cn-hongkong`, `ap-southeast-1`, `ap-southeast-2`, `ap-southeast-3`, `ap-southeast-5`, `ap-northeast-1`, `eu-central-1`]
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] bandwidth: The SAG APP bandwidth that the user can use. Unit: Kbit/s. Maximum value: 2000 Kbit/s.
        :param pulumi.Input[str] client_ip: The IP address of the SAG APP. If you specify this parameter, the current account always uses the specified IP address.Note The IP address must be in the private CIDR block of the SAG client.If you do not specify this parameter, the system automatically allocates an IP address from the private CIDR block of the SAG client. In this case, each re-connection uses a different IP address.
        :param pulumi.Input[str] password: The password used to log on to the SAG APP.Both the user name and the password must be specified. If you specify the user name, the password must be specified, too.
        :param pulumi.Input[str] sag_id: The ID of the SAG instance created for the SAG APP.
        :param pulumi.Input[str] user_mail: The email address of the user. The administrator uses this address to send the account information for logging on to the APP to the user.
        :param pulumi.Input[str] user_name: The user name. User names in the same SAG APP must be unique.Both the user name and the password must be specified. If you specify the user name, the password must be specified, too.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/sag_client_user.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if bandwidth is None:
                raise TypeError("Missing required property 'bandwidth'")
            __props__['bandwidth'] = bandwidth
            __props__['client_ip'] = client_ip
            __props__['kms_encrypted_password'] = kms_encrypted_password
            __props__['kms_encryption_context'] = kms_encryption_context
            __props__['password'] = password
            if sag_id is None:
                raise TypeError("Missing required property 'sag_id'")
            __props__['sag_id'] = sag_id
            if user_mail is None:
                raise TypeError("Missing required property 'user_mail'")
            __props__['user_mail'] = user_mail
            __props__['user_name'] = user_name
        super(ClientUser, __self__).__init__(
            'alicloud:rocketmq/clientUser:ClientUser',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, bandwidth=None, client_ip=None, kms_encrypted_password=None, kms_encryption_context=None, password=None, sag_id=None, user_mail=None, user_name=None):
        """
        Get an existing ClientUser resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] bandwidth: The SAG APP bandwidth that the user can use. Unit: Kbit/s. Maximum value: 2000 Kbit/s.
        :param pulumi.Input[str] client_ip: The IP address of the SAG APP. If you specify this parameter, the current account always uses the specified IP address.Note The IP address must be in the private CIDR block of the SAG client.If you do not specify this parameter, the system automatically allocates an IP address from the private CIDR block of the SAG client. In this case, each re-connection uses a different IP address.
        :param pulumi.Input[str] password: The password used to log on to the SAG APP.Both the user name and the password must be specified. If you specify the user name, the password must be specified, too.
        :param pulumi.Input[str] sag_id: The ID of the SAG instance created for the SAG APP.
        :param pulumi.Input[str] user_mail: The email address of the user. The administrator uses this address to send the account information for logging on to the APP to the user.
        :param pulumi.Input[str] user_name: The user name. User names in the same SAG APP must be unique.Both the user name and the password must be specified. If you specify the user name, the password must be specified, too.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/sag_client_user.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["bandwidth"] = bandwidth
        __props__["client_ip"] = client_ip
        __props__["kms_encrypted_password"] = kms_encrypted_password
        __props__["kms_encryption_context"] = kms_encryption_context
        __props__["password"] = password
        __props__["sag_id"] = sag_id
        __props__["user_mail"] = user_mail
        __props__["user_name"] = user_name
        return ClientUser(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ImageCopy(pulumi.CustomResource):
    description: pulumi.Output[str]
    """
    The description of the image. It must be 2 to 256 characters in length and must not start with http:// or https://. Default value: null.
    """
    encrypted: pulumi.Output[bool]
    """
    Indicates whether to encrypt the image.
    """
    force: pulumi.Output[bool]
    """
    Indicates whether to force delete the custom image, Default is `false`. 
    - true：Force deletes the custom image, regardless of whether the image is currently being used by other instances.
    - false：Verifies that the image is not currently in use by any other instances before deleting the image.
    """
    image_name: pulumi.Output[str]
    """
    The image name. It must be 2 to 128 characters in length, and must begin with a letter or Chinese character (beginning with http:// or https:// is not allowed). It can contain digits, colons (:), underscores (_), or hyphens (-). Default value: null.
    """
    kms_key_id: pulumi.Output[str]
    """
    Key ID used to encrypt the image.
    """
    name: pulumi.Output[str]
    source_image_id: pulumi.Output[str]
    """
    The source image ID.
    """
    source_region_id: pulumi.Output[str]
    """
    The ID of the region to which the source custom image belongs. You can call [DescribeRegions](https://www.alibabacloud.com/help/doc-detail/25609.htm) to view the latest regions of Alibaba Cloud.
    """
    tags: pulumi.Output[dict]
    """
    The tag value of an image. The value of N ranges from 1 to 20.
    """
    def __init__(__self__, resource_name, opts=None, description=None, encrypted=None, force=None, image_name=None, kms_key_id=None, name=None, source_image_id=None, source_region_id=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Copies a custom image from one region to another. You can use copied images to perform operations in the target region, such as creating instances (RunInstances) and replacing system disks (ReplaceSystemDisk).
        
        > **NOTE:** You can only copy the custom image when it is in the Available state.
        
        > **NOTE:** You can only copy the image belonging to your Alibaba Cloud account. Images cannot be copied from one account to another.
        
        > **NOTE:** If the copying is not completed, you cannot call DeleteImage to delete the image but you can call CancelCopyImage to cancel the copying.
        
        > **NOTE:** Available in 1.66.0+.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the image. It must be 2 to 256 characters in length and must not start with http:// or https://. Default value: null.
        :param pulumi.Input[bool] encrypted: Indicates whether to encrypt the image.
        :param pulumi.Input[bool] force: Indicates whether to force delete the custom image, Default is `false`. 
               - true：Force deletes the custom image, regardless of whether the image is currently being used by other instances.
               - false：Verifies that the image is not currently in use by any other instances before deleting the image.
        :param pulumi.Input[str] image_name: The image name. It must be 2 to 128 characters in length, and must begin with a letter or Chinese character (beginning with http:// or https:// is not allowed). It can contain digits, colons (:), underscores (_), or hyphens (-). Default value: null.
        :param pulumi.Input[str] kms_key_id: Key ID used to encrypt the image.
        :param pulumi.Input[str] source_image_id: The source image ID.
        :param pulumi.Input[str] source_region_id: The ID of the region to which the source custom image belongs. You can call [DescribeRegions](https://www.alibabacloud.com/help/doc-detail/25609.htm) to view the latest regions of Alibaba Cloud.
        :param pulumi.Input[dict] tags: The tag value of an image. The value of N ranges from 1 to 20.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/image_copy.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            __props__['encrypted'] = encrypted
            __props__['force'] = force
            __props__['image_name'] = image_name
            __props__['kms_key_id'] = kms_key_id
            __props__['name'] = name
            if source_image_id is None:
                raise TypeError("Missing required property 'source_image_id'")
            __props__['source_image_id'] = source_image_id
            if source_region_id is None:
                raise TypeError("Missing required property 'source_region_id'")
            __props__['source_region_id'] = source_region_id
            __props__['tags'] = tags
        super(ImageCopy, __self__).__init__(
            'alicloud:ecs/imageCopy:ImageCopy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, description=None, encrypted=None, force=None, image_name=None, kms_key_id=None, name=None, source_image_id=None, source_region_id=None, tags=None):
        """
        Get an existing ImageCopy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the image. It must be 2 to 256 characters in length and must not start with http:// or https://. Default value: null.
        :param pulumi.Input[bool] encrypted: Indicates whether to encrypt the image.
        :param pulumi.Input[bool] force: Indicates whether to force delete the custom image, Default is `false`. 
               - true：Force deletes the custom image, regardless of whether the image is currently being used by other instances.
               - false：Verifies that the image is not currently in use by any other instances before deleting the image.
        :param pulumi.Input[str] image_name: The image name. It must be 2 to 128 characters in length, and must begin with a letter or Chinese character (beginning with http:// or https:// is not allowed). It can contain digits, colons (:), underscores (_), or hyphens (-). Default value: null.
        :param pulumi.Input[str] kms_key_id: Key ID used to encrypt the image.
        :param pulumi.Input[str] source_image_id: The source image ID.
        :param pulumi.Input[str] source_region_id: The ID of the region to which the source custom image belongs. You can call [DescribeRegions](https://www.alibabacloud.com/help/doc-detail/25609.htm) to view the latest regions of Alibaba Cloud.
        :param pulumi.Input[dict] tags: The tag value of an image. The value of N ranges from 1 to 20.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/image_copy.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["description"] = description
        __props__["encrypted"] = encrypted
        __props__["force"] = force
        __props__["image_name"] = image_name
        __props__["kms_key_id"] = kms_key_id
        __props__["name"] = name
        __props__["source_image_id"] = source_image_id
        __props__["source_region_id"] = source_region_id
        __props__["tags"] = tags
        return ImageCopy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class RouteEntry(pulumi.CustomResource):
    next_hop: pulumi.Output[str]
    """
    The next hop of the destination route.
    """
    publish_vpc: pulumi.Output[bool]
    """
    Whether to issue the destination route to the VPC.
    """
    route_dest: pulumi.Output[str]
    """
    The destination network segment of the destination route.
    """
    vpn_gateway_id: pulumi.Output[str]
    """
    The id of the vpn gateway.
    """
    weight: pulumi.Output[float]
    """
    The value should be 0 or 100.
    """
    def __init__(__self__, resource_name, opts=None, next_hop=None, publish_vpc=None, route_dest=None, vpn_gateway_id=None, weight=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a RouteEntry resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] next_hop: The next hop of the destination route.
        :param pulumi.Input[bool] publish_vpc: Whether to issue the destination route to the VPC.
        :param pulumi.Input[str] route_dest: The destination network segment of the destination route.
        :param pulumi.Input[str] vpn_gateway_id: The id of the vpn gateway.
        :param pulumi.Input[float] weight: The value should be 0 or 100.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/vpn_route_entry.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if next_hop is None:
                raise TypeError("Missing required property 'next_hop'")
            __props__['next_hop'] = next_hop
            if publish_vpc is None:
                raise TypeError("Missing required property 'publish_vpc'")
            __props__['publish_vpc'] = publish_vpc
            if route_dest is None:
                raise TypeError("Missing required property 'route_dest'")
            __props__['route_dest'] = route_dest
            if vpn_gateway_id is None:
                raise TypeError("Missing required property 'vpn_gateway_id'")
            __props__['vpn_gateway_id'] = vpn_gateway_id
            if weight is None:
                raise TypeError("Missing required property 'weight'")
            __props__['weight'] = weight
        super(RouteEntry, __self__).__init__(
            'alicloud:vpn/routeEntry:RouteEntry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, next_hop=None, publish_vpc=None, route_dest=None, vpn_gateway_id=None, weight=None):
        """
        Get an existing RouteEntry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] next_hop: The next hop of the destination route.
        :param pulumi.Input[bool] publish_vpc: Whether to issue the destination route to the VPC.
        :param pulumi.Input[str] route_dest: The destination network segment of the destination route.
        :param pulumi.Input[str] vpn_gateway_id: The id of the vpn gateway.
        :param pulumi.Input[float] weight: The value should be 0 or 100.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/vpn_route_entry.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["next_hop"] = next_hop
        __props__["publish_vpc"] = publish_vpc
        __props__["route_dest"] = route_dest
        __props__["vpn_gateway_id"] = vpn_gateway_id
        __props__["weight"] = weight
        return RouteEntry(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class NetworkAclEntries(pulumi.CustomResource):
    egresses: pulumi.Output[list]
    """
    List of the egress entries of the network acl. The order of the egress entries determines the priority. The details see Block Egress.
    
      * `description` (`str`) - The description of the egress entry.
      * `destinationCidrIp` (`str`) - The destination ip of the egress entry.
      * `entryType` (`str`) - The entry type of the egress entry. It must be `custom` or `system`. Default value is `custom`.
      * `name` (`str`) - The name of the egress entry.
      * `policy` (`str`) - The policy of the egress entry. It must be `accept` or `drop`.
      * `port` (`str`) - The port of the egress entry.
      * `protocol` (`str`) - The protocol of the egress entry.
    """
    ingresses: pulumi.Output[list]
    """
    List of the ingress entries of the network acl. The order of the ingress entries determines the priority. The details see Block Ingress.
    
      * `description` (`str`) - The description of the egress entry.
      * `entryType` (`str`) - The entry type of the egress entry. It must be `custom` or `system`. Default value is `custom`.
      * `name` (`str`) - The name of the egress entry.
      * `policy` (`str`) - The policy of the egress entry. It must be `accept` or `drop`.
      * `port` (`str`) - The port of the egress entry.
      * `protocol` (`str`) - The protocol of the egress entry.
      * `source_cidr_ip` (`str`) - The source ip of the ingress entry.
    """
    network_acl_id: pulumi.Output[str]
    """
    The id of the network acl, the field can't be changed.
    """
    def __init__(__self__, resource_name, opts=None, egresses=None, ingresses=None, network_acl_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a network acl entries resource to create ingress and egress entries.
        
        > **NOTE:** Available in 1.45.0+. Currently, the resource are only available in Hongkong(cn-hongkong), India(ap-south-1), and Indonesia(ap-southeast-1) regions.
        
        > **NOTE:** It doesn't support concurrency and the order of the ingress and egress entries determines the priority.
        
        > **NOTE:** Using this resource need to open a whitelist.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] egresses: List of the egress entries of the network acl. The order of the egress entries determines the priority. The details see Block Egress.
        :param pulumi.Input[list] ingresses: List of the ingress entries of the network acl. The order of the ingress entries determines the priority. The details see Block Ingress.
        :param pulumi.Input[str] network_acl_id: The id of the network acl, the field can't be changed.
        
        The **egresses** object supports the following:
        
          * `description` (`pulumi.Input[str]`) - The description of the egress entry.
          * `destinationCidrIp` (`pulumi.Input[str]`) - The destination ip of the egress entry.
          * `entryType` (`pulumi.Input[str]`) - The entry type of the egress entry. It must be `custom` or `system`. Default value is `custom`.
          * `name` (`pulumi.Input[str]`) - The name of the egress entry.
          * `policy` (`pulumi.Input[str]`) - The policy of the egress entry. It must be `accept` or `drop`.
          * `port` (`pulumi.Input[str]`) - The port of the egress entry.
          * `protocol` (`pulumi.Input[str]`) - The protocol of the egress entry.
        
        The **ingresses** object supports the following:
        
          * `description` (`pulumi.Input[str]`) - The description of the egress entry.
          * `entryType` (`pulumi.Input[str]`) - The entry type of the egress entry. It must be `custom` or `system`. Default value is `custom`.
          * `name` (`pulumi.Input[str]`) - The name of the egress entry.
          * `policy` (`pulumi.Input[str]`) - The policy of the egress entry. It must be `accept` or `drop`.
          * `port` (`pulumi.Input[str]`) - The port of the egress entry.
          * `protocol` (`pulumi.Input[str]`) - The protocol of the egress entry.
          * `source_cidr_ip` (`pulumi.Input[str]`) - The source ip of the ingress entry.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/network_acl_entries.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['egresses'] = egresses
            __props__['ingresses'] = ingresses
            if network_acl_id is None:
                raise TypeError("Missing required property 'network_acl_id'")
            __props__['network_acl_id'] = network_acl_id
        super(NetworkAclEntries, __self__).__init__(
            'alicloud:vpc/networkAclEntries:NetworkAclEntries',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, egresses=None, ingresses=None, network_acl_id=None):
        """
        Get an existing NetworkAclEntries resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] egresses: List of the egress entries of the network acl. The order of the egress entries determines the priority. The details see Block Egress.
        :param pulumi.Input[list] ingresses: List of the ingress entries of the network acl. The order of the ingress entries determines the priority. The details see Block Ingress.
        :param pulumi.Input[str] network_acl_id: The id of the network acl, the field can't be changed.
        
        The **egresses** object supports the following:
        
          * `description` (`pulumi.Input[str]`) - The description of the egress entry.
          * `destinationCidrIp` (`pulumi.Input[str]`) - The destination ip of the egress entry.
          * `entryType` (`pulumi.Input[str]`) - The entry type of the egress entry. It must be `custom` or `system`. Default value is `custom`.
          * `name` (`pulumi.Input[str]`) - The name of the egress entry.
          * `policy` (`pulumi.Input[str]`) - The policy of the egress entry. It must be `accept` or `drop`.
          * `port` (`pulumi.Input[str]`) - The port of the egress entry.
          * `protocol` (`pulumi.Input[str]`) - The protocol of the egress entry.
        
        The **ingresses** object supports the following:
        
          * `description` (`pulumi.Input[str]`) - The description of the egress entry.
          * `entryType` (`pulumi.Input[str]`) - The entry type of the egress entry. It must be `custom` or `system`. Default value is `custom`.
          * `name` (`pulumi.Input[str]`) - The name of the egress entry.
          * `policy` (`pulumi.Input[str]`) - The policy of the egress entry. It must be `accept` or `drop`.
          * `port` (`pulumi.Input[str]`) - The port of the egress entry.
          * `protocol` (`pulumi.Input[str]`) - The protocol of the egress entry.
          * `source_cidr_ip` (`pulumi.Input[str]`) - The source ip of the ingress entry.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/network_acl_entries.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["egresses"] = egresses
        __props__["ingresses"] = ingresses
        __props__["network_acl_id"] = network_acl_id
        return NetworkAclEntries(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class LogTailConfig(pulumi.CustomResource):
    input_detail: pulumi.Output[str]
    """
    The logtail configure the required JSON files. ([Refer to details](https://www.alibabacloud.com/help/doc-detail/29058.htm))
    """
    input_type: pulumi.Output[str]
    """
    The input type. Currently only two types of files and plugin are supported.
    """
    log_sample: pulumi.Output[str]
    """
    （Optional）The log sample of the Logtail configuration. The log size cannot exceed 1,000 bytes.
    """
    logstore: pulumi.Output[str]
    """
    The log store name to the query index belongs.
    """
    name: pulumi.Output[str]
    """
    The Logtail configuration name, which is unique in the same project.
    """
    output_type: pulumi.Output[str]
    """
    The output type. Currently, only LogService is supported.
    """
    project: pulumi.Output[str]
    """
    The project name to the log store belongs.
    """
    def __init__(__self__, resource_name, opts=None, input_detail=None, input_type=None, log_sample=None, logstore=None, name=None, output_type=None, project=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a LogTailConfig resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] input_detail: The logtail configure the required JSON files. ([Refer to details](https://www.alibabacloud.com/help/doc-detail/29058.htm))
        :param pulumi.Input[str] input_type: The input type. Currently only two types of files and plugin are supported.
        :param pulumi.Input[str] log_sample: （Optional）The log sample of the Logtail configuration. The log size cannot exceed 1,000 bytes.
        :param pulumi.Input[str] logstore: The log store name to the query index belongs.
        :param pulumi.Input[str] name: The Logtail configuration name, which is unique in the same project.
        :param pulumi.Input[str] output_type: The output type. Currently, only LogService is supported.
        :param pulumi.Input[str] project: The project name to the log store belongs.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/logtail_config.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if input_detail is None:
                raise TypeError("Missing required property 'input_detail'")
            __props__['input_detail'] = input_detail
            if input_type is None:
                raise TypeError("Missing required property 'input_type'")
            __props__['input_type'] = input_type
            __props__['log_sample'] = log_sample
            if logstore is None:
                raise TypeError("Missing required property 'logstore'")
            __props__['logstore'] = logstore
            __props__['name'] = name
            if output_type is None:
                raise TypeError("Missing required property 'output_type'")
            __props__['output_type'] = output_type
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
        super(LogTailConfig, __self__).__init__(
            'alicloud:log/logTailConfig:LogTailConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, input_detail=None, input_type=None, log_sample=None, logstore=None, name=None, output_type=None, project=None):
        """
        Get an existing LogTailConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] input_detail: The logtail configure the required JSON files. ([Refer to details](https://www.alibabacloud.com/help/doc-detail/29058.htm))
        :param pulumi.Input[str] input_type: The input type. Currently only two types of files and plugin are supported.
        :param pulumi.Input[str] log_sample: （Optional）The log sample of the Logtail configuration. The log size cannot exceed 1,000 bytes.
        :param pulumi.Input[str] logstore: The log store name to the query index belongs.
        :param pulumi.Input[str] name: The Logtail configuration name, which is unique in the same project.
        :param pulumi.Input[str] output_type: The output type. Currently, only LogService is supported.
        :param pulumi.Input[str] project: The project name to the log store belongs.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/logtail_config.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["input_detail"] = input_detail
        __props__["input_type"] = input_type
        __props__["log_sample"] = log_sample
        __props__["logstore"] = logstore
        __props__["name"] = name
        __props__["output_type"] = output_type
        __props__["project"] = project
        return LogTailConfig(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Record(pulumi.CustomResource):
    host_record: pulumi.Output[str]
    """
    Host record for the domain record. This host_record can have at most 253 characters, and each part split with "." can have at most 63 characters, and must contain only alphanumeric characters or hyphens, such as "-",".","*","@",  and must not begin or end with "-".
    """
    locked: pulumi.Output[bool]
    name: pulumi.Output[str]
    """
    Name of the domain. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
    """
    priority: pulumi.Output[float]
    """
    The priority of domain record. Valid values are `[1-10]`. When the `type` is `MX`, this parameter is required.
    """
    routing: pulumi.Output[str]
    """
    The resolution line of domain record. Valid values are `default`, `telecom`, `unicom`, `mobile`, `oversea`, `edu`, `drpeng`, `btvn`, .etc. When the `type` is `FORWORD_URL`, this parameter must be `default`. Default value is `default`. For checking all resolution lines enumeration please visit [Alibaba Cloud DNS doc](https://www.alibabacloud.com/help/doc-detail/34339.htm) or using dns.getResolutionLines in data source to get the value. 
    """
    status: pulumi.Output[str]
    """
    The record status. `Enable` or `Disable`.
    """
    ttl: pulumi.Output[float]
    """
    The effective time of domain record. Its scope depends on the edition of the cloud resolution. Free is `[600, 86400]`, Basic is `[120, 86400]`, Standard is `[60, 86400]`, Ultimate is `[10, 86400]`, Exclusive is `[1, 86400]`. Default value is `600`.
    """
    type: pulumi.Output[str]
    """
    The type of domain record. Valid values are `A`,`NS`,`MX`,`TXT`,`CNAME`,`SRV`,`AAAA`,`CAA`, `REDIRECT_URL` and `FORWORD_URL`.
    """
    value: pulumi.Output[str]
    """
    The value of domain record, When the `type` is `MX`,`NS`,`CNAME`,`SRV`, the server will treat the `value` as a fully qualified domain name, so it's no need to add a `.` at the end.
    """
    def __init__(__self__, resource_name, opts=None, host_record=None, name=None, priority=None, routing=None, ttl=None, type=None, value=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a DNS Record resource.
        
        > **NOTE:** When the site is an international site, the `type` neither supports `REDIRECT_URL` nor `REDIRECT_URL`
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] host_record: Host record for the domain record. This host_record can have at most 253 characters, and each part split with "." can have at most 63 characters, and must contain only alphanumeric characters or hyphens, such as "-",".","*","@",  and must not begin or end with "-".
        :param pulumi.Input[str] name: Name of the domain. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        :param pulumi.Input[float] priority: The priority of domain record. Valid values are `[1-10]`. When the `type` is `MX`, this parameter is required.
        :param pulumi.Input[str] routing: The resolution line of domain record. Valid values are `default`, `telecom`, `unicom`, `mobile`, `oversea`, `edu`, `drpeng`, `btvn`, .etc. When the `type` is `FORWORD_URL`, this parameter must be `default`. Default value is `default`. For checking all resolution lines enumeration please visit [Alibaba Cloud DNS doc](https://www.alibabacloud.com/help/doc-detail/34339.htm) or using dns.getResolutionLines in data source to get the value. 
        :param pulumi.Input[float] ttl: The effective time of domain record. Its scope depends on the edition of the cloud resolution. Free is `[600, 86400]`, Basic is `[120, 86400]`, Standard is `[60, 86400]`, Ultimate is `[10, 86400]`, Exclusive is `[1, 86400]`. Default value is `600`.
        :param pulumi.Input[str] type: The type of domain record. Valid values are `A`,`NS`,`MX`,`TXT`,`CNAME`,`SRV`,`AAAA`,`CAA`, `REDIRECT_URL` and `FORWORD_URL`.
        :param pulumi.Input[str] value: The value of domain record, When the `type` is `MX`,`NS`,`CNAME`,`SRV`, the server will treat the `value` as a fully qualified domain name, so it's no need to add a `.` at the end.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/dns_record.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if host_record is None:
                raise TypeError("Missing required property 'host_record'")
            __props__['host_record'] = host_record
            __props__['name'] = name
            __props__['priority'] = priority
            __props__['routing'] = routing
            __props__['ttl'] = ttl
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
            if value is None:
                raise TypeError("Missing required property 'value'")
            __props__['value'] = value
            __props__['locked'] = None
            __props__['status'] = None
        super(Record, __self__).__init__(
            'alicloud:dns/record:Record',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, host_record=None, locked=None, name=None, priority=None, routing=None, status=None, ttl=None, type=None, value=None):
        """
        Get an existing Record resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] host_record: Host record for the domain record. This host_record can have at most 253 characters, and each part split with "." can have at most 63 characters, and must contain only alphanumeric characters or hyphens, such as "-",".","*","@",  and must not begin or end with "-".
        :param pulumi.Input[str] name: Name of the domain. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        :param pulumi.Input[float] priority: The priority of domain record. Valid values are `[1-10]`. When the `type` is `MX`, this parameter is required.
        :param pulumi.Input[str] routing: The resolution line of domain record. Valid values are `default`, `telecom`, `unicom`, `mobile`, `oversea`, `edu`, `drpeng`, `btvn`, .etc. When the `type` is `FORWORD_URL`, this parameter must be `default`. Default value is `default`. For checking all resolution lines enumeration please visit [Alibaba Cloud DNS doc](https://www.alibabacloud.com/help/doc-detail/34339.htm) or using dns.getResolutionLines in data source to get the value. 
        :param pulumi.Input[str] status: The record status. `Enable` or `Disable`.
        :param pulumi.Input[float] ttl: The effective time of domain record. Its scope depends on the edition of the cloud resolution. Free is `[600, 86400]`, Basic is `[120, 86400]`, Standard is `[60, 86400]`, Ultimate is `[10, 86400]`, Exclusive is `[1, 86400]`. Default value is `600`.
        :param pulumi.Input[str] type: The type of domain record. Valid values are `A`,`NS`,`MX`,`TXT`,`CNAME`,`SRV`,`AAAA`,`CAA`, `REDIRECT_URL` and `FORWORD_URL`.
        :param pulumi.Input[str] value: The value of domain record, When the `type` is `MX`,`NS`,`CNAME`,`SRV`, the server will treat the `value` as a fully qualified domain name, so it's no need to add a `.` at the end.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/dns_record.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["host_record"] = host_record
        __props__["locked"] = locked
        __props__["name"] = name
        __props__["priority"] = priority
        __props__["routing"] = routing
        __props__["status"] = status
        __props__["ttl"] = ttl
        __props__["type"] = type
        __props__["value"] = value
        return Record(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class MountTarget(pulumi.CustomResource):
    access_group_name: pulumi.Output[str]
    """
    Permission group name.
    """
    file_system_id: pulumi.Output[str]
    """
    File system ID.
    """
    status: pulumi.Output[str]
    """
    Whether the MountTarget is active. An inactive MountTarget is inusable. Valid values are Active(default) and Inactive.
    """
    vswitch_id: pulumi.Output[str]
    """
    VSwitch ID.
    """
    def __init__(__self__, resource_name, opts=None, access_group_name=None, file_system_id=None, status=None, vswitch_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Nas Mount Target resource.
        
        > NOTE: Available in v1.34.0+.
        
        > NOTE: Currently this resource support create a mount point in a classic network only when current region is China mainland regions.
        
        > NOTE: You must grant NAS with specific RAM permissions when creating a classic mount targets,
        and it only can be achieved by creating a classic mount target mannually.
        See [Add a mount point](https://www.alibabacloud.com/help/doc-detail/60431.htm) and [Why do I need RAM permissions to create a mount point in a classic network](https://www.alibabacloud.com/help/faq-detail/42176.htm).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_group_name: Permission group name.
        :param pulumi.Input[str] file_system_id: File system ID.
        :param pulumi.Input[str] status: Whether the MountTarget is active. An inactive MountTarget is inusable. Valid values are Active(default) and Inactive.
        :param pulumi.Input[str] vswitch_id: VSwitch ID.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/nas_mount_target.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if access_group_name is None:
                raise TypeError("Missing required property 'access_group_name'")
            __props__['access_group_name'] = access_group_name
            if file_system_id is None:
                raise TypeError("Missing required property 'file_system_id'")
            __props__['file_system_id'] = file_system_id
            __props__['status'] = status
            __props__['vswitch_id'] = vswitch_id
        super(MountTarget, __self__).__init__(
            'alicloud:nas/mountTarget:MountTarget',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, access_group_name=None, file_system_id=None, status=None, vswitch_id=None):
        """
        Get an existing MountTarget resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_group_name: Permission group name.
        :param pulumi.Input[str] file_system_id: File system ID.
        :param pulumi.Input[str] status: Whether the MountTarget is active. An inactive MountTarget is inusable. Valid values are Active(default) and Inactive.
        :param pulumi.Input[str] vswitch_id: VSwitch ID.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/nas_mount_target.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["access_group_name"] = access_group_name
        __props__["file_system_id"] = file_system_id
        __props__["status"] = status
        __props__["vswitch_id"] = vswitch_id
        return MountTarget(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class AccessKey(pulumi.CustomResource):
    encrypted_secret: pulumi.Output[str]
    key_fingerprint: pulumi.Output[str]
    """
    The fingerprint of the PGP key used to encrypt the secret
    """
    pgp_key: pulumi.Output[str]
    """
    Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
    """
    secret_file: pulumi.Output[str]
    """
    The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
    """
    status: pulumi.Output[str]
    """
    Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
    """
    user_name: pulumi.Output[str]
    """
    Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
    """
    def __init__(__self__, resource_name, opts=None, pgp_key=None, secret_file=None, status=None, user_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a RAM User access key resource.
        
        > **NOTE:**  You should set the `secret_file` if you want to get the access key.  
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] pgp_key: Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        :param pulumi.Input[str] secret_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[str] status: Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/ram_access_key.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['pgp_key'] = pgp_key
            __props__['secret_file'] = secret_file
            __props__['status'] = status
            __props__['user_name'] = user_name
            __props__['encrypted_secret'] = None
            __props__['key_fingerprint'] = None
        super(AccessKey, __self__).__init__(
            'alicloud:ram/accessKey:AccessKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, encrypted_secret=None, key_fingerprint=None, pgp_key=None, secret_file=None, status=None, user_name=None):
        """
        Get an existing AccessKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key_fingerprint: The fingerprint of the PGP key used to encrypt the secret
        :param pulumi.Input[str] pgp_key: Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        :param pulumi.Input[str] secret_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[str] status: Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/ram_access_key.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["encrypted_secret"] = encrypted_secret
        __props__["key_fingerprint"] = key_fingerprint
        __props__["pgp_key"] = pgp_key
        __props__["secret_file"] = secret_file
        __props__["status"] = status
        __props__["user_name"] = user_name
        return AccessKey(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class LifecycleHook(pulumi.CustomResource):
    default_result: pulumi.Output[str]
    heartbeat_timeout: pulumi.Output[float]
    lifecycle_transition: pulumi.Output[str]
    name: pulumi.Output[str]
    notification_arn: pulumi.Output[str]
    notification_metadata: pulumi.Output[str]
    scaling_group_id: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, default_result=None, heartbeat_timeout=None, lifecycle_transition=None, name=None, notification_arn=None, notification_metadata=None, scaling_group_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a LifecycleHook resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['default_result'] = default_result
            __props__['heartbeat_timeout'] = heartbeat_timeout
            if lifecycle_transition is None:
                raise TypeError("Missing required property 'lifecycle_transition'")
            __props__['lifecycle_transition'] = lifecycle_transition
            __props__['name'] = name
            __props__['notification_arn'] = notification_arn
            __props__['notification_metadata'] = notification_metadata
            if scaling_group_id is None:
                raise TypeError("Missing required property 'scaling_group_id'")
            __props__['scaling_group_id'] = scaling_group_id
        super(LifecycleHook, __self__).__init__(
            'alicloud:ess/lifecycleHook:LifecycleHook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, default_result=None, heartbeat_timeout=None, lifecycle_transition=None, name=None, notification_arn=None, notification_metadata=None, scaling_group_id=None):
        """
        Get an existing LifecycleHook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["default_result"] = default_result
        __props__["heartbeat_timeout"] = heartbeat_timeout
        __props__["lifecycle_transition"] = lifecycle_transition
        __props__["name"] = name
        __props__["notification_arn"] = notification_arn
        __props__["notification_metadata"] = notification_metadata
        __props__["scaling_group_id"] = scaling_group_id
        return LifecycleHook(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class RouterInterfaceConnection(pulumi.CustomResource):
    interface_id: pulumi.Output[str]
    """
    One side router interface ID.
    """
    opposite_interface_id: pulumi.Output[str]
    """
    Another side router interface ID. It must belong the specified "opposite_interface_owner_id" account.
    """
    opposite_interface_owner_id: pulumi.Output[str]
    opposite_router_id: pulumi.Output[str]
    """
    Another side router ID. It must belong the specified "opposite_interface_owner_id" account. It is valid when field "opposite_interface_owner_id" is specified.
    """
    opposite_router_type: pulumi.Output[str]
    """
    Another side router Type. Optional value: VRouter, VBR. It is valid when field "opposite_interface_owner_id" is specified.
    """
    def __init__(__self__, resource_name, opts=None, interface_id=None, opposite_interface_id=None, opposite_interface_owner_id=None, opposite_router_id=None, opposite_router_type=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a VPC router interface connection resource to connect two router interfaces which are in two different VPCs.
        After that, all of the two router interfaces will be active.
        
        > **NOTE:** At present, Router interface does not support changing opposite router interface, the connection delete action is only deactivating it to inactive, not modifying the connection to empty.
        
        > **NOTE:** If you want to changing opposite router interface, you can delete router interface and re-build them.
        
        > **NOTE:** A integrated router interface connection tunnel requires both InitiatingSide and AcceptingSide configuring opposite router interface.
        
        > **NOTE:** Please remember to add a `depends_on` clause in the router interface connection from the InitiatingSide to the AcceptingSide, because the connection from the AcceptingSide to the InitiatingSide must be done first.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] interface_id: One side router interface ID.
        :param pulumi.Input[str] opposite_interface_id: Another side router interface ID. It must belong the specified "opposite_interface_owner_id" account.
        :param pulumi.Input[str] opposite_router_id: Another side router ID. It must belong the specified "opposite_interface_owner_id" account. It is valid when field "opposite_interface_owner_id" is specified.
        :param pulumi.Input[str] opposite_router_type: Another side router Type. Optional value: VRouter, VBR. It is valid when field "opposite_interface_owner_id" is specified.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/router_interface_connection.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if interface_id is None:
                raise TypeError("Missing required property 'interface_id'")
            __props__['interface_id'] = interface_id
            if opposite_interface_id is None:
                raise TypeError("Missing required property 'opposite_interface_id'")
            __props__['opposite_interface_id'] = opposite_interface_id
            __props__['opposite_interface_owner_id'] = opposite_interface_owner_id
            __props__['opposite_router_id'] = opposite_router_id
            __props__['opposite_router_type'] = opposite_router_type
        super(RouterInterfaceConnection, __self__).__init__(
            'alicloud:vpc/routerInterfaceConnection:RouterInterfaceConnection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, interface_id=None, opposite_interface_id=None, opposite_interface_owner_id=None, opposite_router_id=None, opposite_router_type=None):
        """
        Get an existing RouterInterfaceConnection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] interface_id: One side router interface ID.
        :param pulumi.Input[str] opposite_interface_id: Another side router interface ID. It must belong the specified "opposite_interface_owner_id" account.
        :param pulumi.Input[str] opposite_router_id: Another side router ID. It must belong the specified "opposite_interface_owner_id" account. It is valid when field "opposite_interface_owner_id" is specified.
        :param pulumi.Input[str] opposite_router_type: Another side router Type. Optional value: VRouter, VBR. It is valid when field "opposite_interface_owner_id" is specified.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/router_interface_connection.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["interface_id"] = interface_id
        __props__["opposite_interface_id"] = opposite_interface_id
        __props__["opposite_interface_owner_id"] = opposite_interface_owner_id
        __props__["opposite_router_id"] = opposite_router_id
        __props__["opposite_router_type"] = opposite_router_type
        return RouterInterfaceConnection(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ShardingInstance(pulumi.CustomResource):
    account_password: pulumi.Output[str]
    """
    Password of the root account. It is a string of 6 to 32 characters and is composed of letters, numbers, and underlines.
    """
    backup_periods: pulumi.Output[list]
    """
    MongoDB Instance backup period. It is required when `backup_time` was existed. Valid values: [Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday]. Default to [Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday]
    """
    backup_time: pulumi.Output[str]
    """
    MongoDB instance backup time. It is required when `backup_period` was existed. In the format of HH:mmZ- HH:mmZ. Time setting interval is one hour. If not set, the system will return a default, like "23:00Z-24:00Z".
    """
    engine_version: pulumi.Output[str]
    """
    Database version. Value options can refer to the latest docs [CreateDBInstance](https://www.alibabacloud.com/help/zh/doc-detail/61884.htm) `EngineVersion`. 
    * `storage_engine` (Optional, ForceNew) Storage engine: WiredTiger or RocksDB. System Default value: WiredTiger.
    """
    instance_charge_type: pulumi.Output[str]
    """
    Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
    """
    kms_encrypted_password: pulumi.Output[str]
    """
    An KMS encrypts password used to a instance. If the `account_password` is filled in, this field will be ignored.
    """
    kms_encryption_context: pulumi.Output[dict]
    """
    An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
    """
    mongo_lists: pulumi.Output[list]
    """
    The mongo-node count can be purchased is in range of [2, 32].
    * `node_class` -(Required) Node specification. see [Instance specifications](https://www.alibabacloud.com/help/doc-detail/57141.htm).
    
      * `connectString` (`str`) - Mongo node connection string
      * `nodeClass` (`str`)
      * `nodeId` (`str`) - The ID of the shard-node.
      * `port` (`float`) - Mongo node port
        * `shard_list`
    """
    name: pulumi.Output[str]
    """
    The name of DB instance. It a string of 2 to 256 characters.
    """
    period: pulumi.Output[float]
    """
    The duration that you will buy DB instance (in month). It is valid when instance_charge_type is `PrePaid`. Valid values: [1~9], 12, 24, 36. System default to 1.
    """
    retention_period: pulumi.Output[float]
    """
    Instance log backup retention days. Available in 1.42.0+.
    """
    security_ip_lists: pulumi.Output[list]
    """
    List of IP addresses allowed to access all databases of an instance. The list contains up to 1,000 IP addresses, separated by commas. Supported formats include 0.0.0.0/0, 10.23.12.24 (IP), and 10.23.12.24/24 (Classless Inter-Domain Routing (CIDR) mode. /24 represents the length of the prefix in an IP address. The range of the prefix length is [1,32]). System default to `["127.0.0.1"]`.
    """
    shard_lists: pulumi.Output[list]
    """
    the shard-node count can be purchased is in range of [2, 32].
    * `node_class` -(Required) Node specification. see [Instance specifications](https://www.alibabacloud.com/help/doc-detail/57141.htm).
    
      * `nodeClass` (`str`)
      * `nodeId` (`str`) - The ID of the shard-node.
      * `nodeStorage` (`float`) - 
        - Custom storage space; value range: [10, 1,000]
        - 10-GB increments. Unit: GB.
    """
    storage_engine: pulumi.Output[str]
    vswitch_id: pulumi.Output[str]
    """
    The virtual switch ID to launch DB instances in one VPC.
    """
    zone_id: pulumi.Output[str]
    """
    The Zone to launch the DB instance. MongoDB sharding instance does not support multiple-zone.
    If it is a multi-zone and `vswitch_id` is specified, the vswitch must in one of them.
    """
    def __init__(__self__, resource_name, opts=None, account_password=None, backup_periods=None, backup_time=None, engine_version=None, instance_charge_type=None, kms_encrypted_password=None, kms_encryption_context=None, mongo_lists=None, name=None, period=None, security_ip_lists=None, shard_lists=None, storage_engine=None, vswitch_id=None, zone_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a ShardingInstance resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_password: Password of the root account. It is a string of 6 to 32 characters and is composed of letters, numbers, and underlines.
        :param pulumi.Input[list] backup_periods: MongoDB Instance backup period. It is required when `backup_time` was existed. Valid values: [Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday]. Default to [Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday]
        :param pulumi.Input[str] backup_time: MongoDB instance backup time. It is required when `backup_period` was existed. In the format of HH:mmZ- HH:mmZ. Time setting interval is one hour. If not set, the system will return a default, like "23:00Z-24:00Z".
        :param pulumi.Input[str] engine_version: Database version. Value options can refer to the latest docs [CreateDBInstance](https://www.alibabacloud.com/help/zh/doc-detail/61884.htm) `EngineVersion`. 
               * `storage_engine` (Optional, ForceNew) Storage engine: WiredTiger or RocksDB. System Default value: WiredTiger.
        :param pulumi.Input[str] instance_charge_type: Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        :param pulumi.Input[str] kms_encrypted_password: An KMS encrypts password used to a instance. If the `account_password` is filled in, this field will be ignored.
        :param pulumi.Input[dict] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[list] mongo_lists: The mongo-node count can be purchased is in range of [2, 32].
               * `node_class` -(Required) Node specification. see [Instance specifications](https://www.alibabacloud.com/help/doc-detail/57141.htm).
        :param pulumi.Input[str] name: The name of DB instance. It a string of 2 to 256 characters.
        :param pulumi.Input[float] period: The duration that you will buy DB instance (in month). It is valid when instance_charge_type is `PrePaid`. Valid values: [1~9], 12, 24, 36. System default to 1.
        :param pulumi.Input[list] security_ip_lists: List of IP addresses allowed to access all databases of an instance. The list contains up to 1,000 IP addresses, separated by commas. Supported formats include 0.0.0.0/0, 10.23.12.24 (IP), and 10.23.12.24/24 (Classless Inter-Domain Routing (CIDR) mode. /24 represents the length of the prefix in an IP address. The range of the prefix length is [1,32]). System default to `["127.0.0.1"]`.
        :param pulumi.Input[list] shard_lists: the shard-node count can be purchased is in range of [2, 32].
               * `node_class` -(Required) Node specification. see [Instance specifications](https://www.alibabacloud.com/help/doc-detail/57141.htm).
        :param pulumi.Input[str] vswitch_id: The virtual switch ID to launch DB instances in one VPC.
        :param pulumi.Input[str] zone_id: The Zone to launch the DB instance. MongoDB sharding instance does not support multiple-zone.
               If it is a multi-zone and `vswitch_id` is specified, the vswitch must in one of them.
        
        The **mongo_lists** object supports the following:
        
          * `connectString` (`pulumi.Input[str]`) - Mongo node connection string
          * `nodeClass` (`pulumi.Input[str]`)
          * `nodeId` (`pulumi.Input[str]`) - The ID of the shard-node.
          * `port` (`pulumi.Input[float]`) - Mongo node port
            * `shard_list`
        
        The **shard_lists** object supports the following:
        
          * `nodeClass` (`pulumi.Input[str]`)
          * `nodeId` (`pulumi.Input[str]`) - The ID of the shard-node.
          * `nodeStorage` (`pulumi.Input[float]`) - 
            - Custom storage space; value range: [10, 1,000]
            - 10-GB increments. Unit: GB.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/mongodb_sharding_instance.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['account_password'] = account_password
            __props__['backup_periods'] = backup_periods
            __props__['backup_time'] = backup_time
            if engine_version is None:
                raise TypeError("Missing required property 'engine_version'")
            __props__['engine_version'] = engine_version
            __props__['instance_charge_type'] = instance_charge_type
            __props__['kms_encrypted_password'] = kms_encrypted_password
            __props__['kms_encryption_context'] = kms_encryption_context
            if mongo_lists is None:
                raise TypeError("Missing required property 'mongo_lists'")
            __props__['mongo_lists'] = mongo_lists
            __props__['name'] = name
            __props__['period'] = period
            __props__['security_ip_lists'] = security_ip_lists
            if shard_lists is None:
                raise TypeError("Missing required property 'shard_lists'")
            __props__['shard_lists'] = shard_lists
            __props__['storage_engine'] = storage_engine
            __props__['vswitch_id'] = vswitch_id
            __props__['zone_id'] = zone_id
            __props__['retention_period'] = None
        super(ShardingInstance, __self__).__init__(
            'alicloud:mongodb/shardingInstance:ShardingInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, account_password=None, backup_periods=None, backup_time=None, engine_version=None, instance_charge_type=None, kms_encrypted_password=None, kms_encryption_context=None, mongo_lists=None, name=None, period=None, retention_period=None, security_ip_lists=None, shard_lists=None, storage_engine=None, vswitch_id=None, zone_id=None):
        """
        Get an existing ShardingInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_password: Password of the root account. It is a string of 6 to 32 characters and is composed of letters, numbers, and underlines.
        :param pulumi.Input[list] backup_periods: MongoDB Instance backup period. It is required when `backup_time` was existed. Valid values: [Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday]. Default to [Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday]
        :param pulumi.Input[str] backup_time: MongoDB instance backup time. It is required when `backup_period` was existed. In the format of HH:mmZ- HH:mmZ. Time setting interval is one hour. If not set, the system will return a default, like "23:00Z-24:00Z".
        :param pulumi.Input[str] engine_version: Database version. Value options can refer to the latest docs [CreateDBInstance](https://www.alibabacloud.com/help/zh/doc-detail/61884.htm) `EngineVersion`. 
               * `storage_engine` (Optional, ForceNew) Storage engine: WiredTiger or RocksDB. System Default value: WiredTiger.
        :param pulumi.Input[str] instance_charge_type: Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        :param pulumi.Input[str] kms_encrypted_password: An KMS encrypts password used to a instance. If the `account_password` is filled in, this field will be ignored.
        :param pulumi.Input[dict] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[list] mongo_lists: The mongo-node count can be purchased is in range of [2, 32].
               * `node_class` -(Required) Node specification. see [Instance specifications](https://www.alibabacloud.com/help/doc-detail/57141.htm).
        :param pulumi.Input[str] name: The name of DB instance. It a string of 2 to 256 characters.
        :param pulumi.Input[float] period: The duration that you will buy DB instance (in month). It is valid when instance_charge_type is `PrePaid`. Valid values: [1~9], 12, 24, 36. System default to 1.
        :param pulumi.Input[float] retention_period: Instance log backup retention days. Available in 1.42.0+.
        :param pulumi.Input[list] security_ip_lists: List of IP addresses allowed to access all databases of an instance. The list contains up to 1,000 IP addresses, separated by commas. Supported formats include 0.0.0.0/0, 10.23.12.24 (IP), and 10.23.12.24/24 (Classless Inter-Domain Routing (CIDR) mode. /24 represents the length of the prefix in an IP address. The range of the prefix length is [1,32]). System default to `["127.0.0.1"]`.
        :param pulumi.Input[list] shard_lists: the shard-node count can be purchased is in range of [2, 32].
               * `node_class` -(Required) Node specification. see [Instance specifications](https://www.alibabacloud.com/help/doc-detail/57141.htm).
        :param pulumi.Input[str] vswitch_id: The virtual switch ID to launch DB instances in one VPC.
        :param pulumi.Input[str] zone_id: The Zone to launch the DB instance. MongoDB sharding instance does not support multiple-zone.
               If it is a multi-zone and `vswitch_id` is specified, the vswitch must in one of them.
        
        The **mongo_lists** object supports the following:
        
          * `connectString` (`pulumi.Input[str]`) - Mongo node connection string
          * `nodeClass` (`pulumi.Input[str]`)
          * `nodeId` (`pulumi.Input[str]`) - The ID of the shard-node.
          * `port` (`pulumi.Input[float]`) - Mongo node port
            * `shard_list`
        
        The **shard_lists** object supports the following:
        
          * `nodeClass` (`pulumi.Input[str]`)
          * `nodeId` (`pulumi.Input[str]`) - The ID of the shard-node.
          * `nodeStorage` (`pulumi.Input[float]`) - 
            - Custom storage space; value range: [10, 1,000]
            - 10-GB increments. Unit: GB.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/mongodb_sharding_instance.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["account_password"] = account_password
        __props__["backup_periods"] = backup_periods
        __props__["backup_time"] = backup_time
        __props__["engine_version"] = engine_version
        __props__["instance_charge_type"] = instance_charge_type
        __props__["kms_encrypted_password"] = kms_encrypted_password
        __props__["kms_encryption_context"] = kms_encryption_context
        __props__["mongo_lists"] = mongo_lists
        __props__["name"] = name
        __props__["period"] = period
        __props__["retention_period"] = retention_period
        __props__["security_ip_lists"] = security_ip_lists
        __props__["shard_lists"] = shard_lists
        __props__["storage_engine"] = storage_engine
        __props__["vswitch_id"] = vswitch_id
        __props__["zone_id"] = zone_id
        return ShardingInstance(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetQueuesResult:
    """
    A collection of values returned by getQueues.
    """
    def __init__(__self__, name_prefix=None, names=None, output_file=None, queues=None, id=None):
        if name_prefix and not isinstance(name_prefix, str):
            raise TypeError("Expected argument 'name_prefix' to be a str")
        __self__.name_prefix = name_prefix
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        __self__.names = names
        """
        A list of queue names. 
        """
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        __self__.output_file = output_file
        if queues and not isinstance(queues, list):
            raise TypeError("Expected argument 'queues' to be a list")
        __self__.queues = queues
        """
        A list of queues. Each element contains the following attributes:
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetQueuesResult(GetQueuesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQueuesResult(
            name_prefix=self.name_prefix,
            names=self.names,
            output_file=self.output_file,
            queues=self.queues,
            id=self.id)

def get_queues(name_prefix=None,output_file=None,opts=None):
    """
    This data source provides a list of MNS queues in an Alibaba Cloud account according to the specified parameters.
    
    :param str name_prefix: A string to filter resulting queues by their name prefixs.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/d/mns_queues.html.markdown.
    """
    __args__ = dict()

    __args__['namePrefix'] = name_prefix
    __args__['outputFile'] = output_file
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:mns/getQueues:getQueues', __args__, opts=opts).value

    return AwaitableGetQueuesResult(
        name_prefix=__ret__.get('namePrefix'),
        names=__ret__.get('names'),
        output_file=__ret__.get('outputFile'),
        queues=__ret__.get('queues'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Instance(pulumi.CustomResource):
    data_node_amount: pulumi.Output[float]
    """
    The Elasticsearch cluster's data node quantity, between 2 and 50.
    """
    data_node_disk_size: pulumi.Output[float]
    """
    The single data node storage space.
    - `cloud_ssd`: An SSD disk, supports a maximum of 2048 GiB (2 TB).
    - `cloud_efficiency` An ultra disk, supports a maximum of 5120 GiB (5 TB). If the data to be stored is larger than 2048 GiB, an ultra disk can only support the following data sizes (GiB): [`2560`, `3072`, `3584`, `4096`, `4608`, `5120`].
    """
    data_node_disk_type: pulumi.Output[str]
    """
    The data node disk type. Supported values: cloud_ssd, cloud_efficiency.
    """
    data_node_spec: pulumi.Output[str]
    """
    The data node specifications of the Elasticsearch instance.
    """
    description: pulumi.Output[str]
    """
    The description of instance. It a string of 0 to 30 characters.
    """
    domain: pulumi.Output[str]
    """
    Instance connection domain (only VPC network access supported).
    """
    instance_charge_type: pulumi.Output[str]
    """
    Valid values are `PrePaid`, `PostPaid`, Default to `PostPaid`. From version 1.69.0, the Elasticsearch cluster allows you to update your instance_charge_ype from `PostPaid` to `PrePaid`, the following attributes are required: `period`. But, updating from `PostPaid` to `PrePaid` is not supported.
    """
    kibana_domain: pulumi.Output[str]
    """
    Kibana console domain (Internet access supported).
    """
    kibana_port: pulumi.Output[float]
    """
    Kibana console port.
    """
    kibana_whitelists: pulumi.Output[list]
    """
    Set the Kibana's IP whitelist in internet network.
    """
    kms_encrypted_password: pulumi.Output[str]
    """
    An KMS encrypts password used to a instance. If the `password` is filled in, this field will be ignored, but you have to specify one of `password` and `kms_encrypted_password` fields.
    """
    kms_encryption_context: pulumi.Output[dict]
    """
    An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
    """
    master_node_spec: pulumi.Output[str]
    """
    The dedicated master node spec. If specified, dedicated master node will be created.
    """
    password: pulumi.Output[str]
    """
    The password of the instance. The password can be 8 to 30 characters in length and must contain three of the following conditions: uppercase letters, lowercase letters, numbers, and special characters (`!@#$%^&*()_+-=`).
    """
    period: pulumi.Output[float]
    """
    The duration that you will buy Elasticsearch instance (in month). It is valid when instance_charge_type is `PrePaid`. Valid values: [1~9], 12, 24, 36. Default to 1. From version 1.69.2, when to modify this value, the resource can renewal a `PrePaid` instance.
    """
    port: pulumi.Output[float]
    """
    Instance connection port.
    """
    private_whitelists: pulumi.Output[list]
    """
    Set the instance's IP whitelist in VPC network.
    """
    public_whitelists: pulumi.Output[list]
    status: pulumi.Output[str]
    """
    The Elasticsearch instance status. Includes `active`, `activating`, `inactive`. Some operations are denied when status is not `active`.
    """
    version: pulumi.Output[str]
    """
    Elasticsearch version. Supported values: `5.5.3_with_X-Pack`, `6.3_with_X-Pack` and `6.7_with_X-Pack`.
    """
    vswitch_id: pulumi.Output[str]
    """
    The ID of VSwitch.
    """
    zone_count: pulumi.Output[float]
    """
    The Multi-AZ supported for Elasticsearch, between 1 and 3. The `data_node_amount` value must be an integral multiple of the `zone_count` value.
    """
    def __init__(__self__, resource_name, opts=None, data_node_amount=None, data_node_disk_size=None, data_node_disk_type=None, data_node_spec=None, description=None, instance_charge_type=None, kibana_whitelists=None, kms_encrypted_password=None, kms_encryption_context=None, master_node_spec=None, password=None, period=None, private_whitelists=None, public_whitelists=None, version=None, vswitch_id=None, zone_count=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Elasticsearch instance resource. It contains data nodes, dedicated master node(optional) and etc. It can be associated with private IP whitelists and kibana IP whitelist.
        
        > **NOTE:** Only one operation is supported in a request. So if `data_node_spec` and `data_node_disk_size` are both changed, system will respond error.
        
        > **NOTE:** At present, `version` can not be modified once instance has been created.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] data_node_amount: The Elasticsearch cluster's data node quantity, between 2 and 50.
        :param pulumi.Input[float] data_node_disk_size: The single data node storage space.
               - `cloud_ssd`: An SSD disk, supports a maximum of 2048 GiB (2 TB).
               - `cloud_efficiency` An ultra disk, supports a maximum of 5120 GiB (5 TB). If the data to be stored is larger than 2048 GiB, an ultra disk can only support the following data sizes (GiB): [`2560`, `3072`, `3584`, `4096`, `4608`, `5120`].
        :param pulumi.Input[str] data_node_disk_type: The data node disk type. Supported values: cloud_ssd, cloud_efficiency.
        :param pulumi.Input[str] data_node_spec: The data node specifications of the Elasticsearch instance.
        :param pulumi.Input[str] description: The description of instance. It a string of 0 to 30 characters.
        :param pulumi.Input[str] instance_charge_type: Valid values are `PrePaid`, `PostPaid`, Default to `PostPaid`. From version 1.69.0, the Elasticsearch cluster allows you to update your instance_charge_ype from `PostPaid` to `PrePaid`, the following attributes are required: `period`. But, updating from `PostPaid` to `PrePaid` is not supported.
        :param pulumi.Input[list] kibana_whitelists: Set the Kibana's IP whitelist in internet network.
        :param pulumi.Input[str] kms_encrypted_password: An KMS encrypts password used to a instance. If the `password` is filled in, this field will be ignored, but you have to specify one of `password` and `kms_encrypted_password` fields.
        :param pulumi.Input[dict] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[str] master_node_spec: The dedicated master node spec. If specified, dedicated master node will be created.
        :param pulumi.Input[str] password: The password of the instance. The password can be 8 to 30 characters in length and must contain three of the following conditions: uppercase letters, lowercase letters, numbers, and special characters (`!@#$%^&*()_+-=`).
        :param pulumi.Input[float] period: The duration that you will buy Elasticsearch instance (in month). It is valid when instance_charge_type is `PrePaid`. Valid values: [1~9], 12, 24, 36. Default to 1. From version 1.69.2, when to modify this value, the resource can renewal a `PrePaid` instance.
        :param pulumi.Input[list] private_whitelists: Set the instance's IP whitelist in VPC network.
        :param pulumi.Input[str] version: Elasticsearch version. Supported values: `5.5.3_with_X-Pack`, `6.3_with_X-Pack` and `6.7_with_X-Pack`.
        :param pulumi.Input[str] vswitch_id: The ID of VSwitch.
        :param pulumi.Input[float] zone_count: The Multi-AZ supported for Elasticsearch, between 1 and 3. The `data_node_amount` value must be an integral multiple of the `zone_count` value.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/elasticsearch_instance.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if data_node_amount is None:
                raise TypeError("Missing required property 'data_node_amount'")
            __props__['data_node_amount'] = data_node_amount
            if data_node_disk_size is None:
                raise TypeError("Missing required property 'data_node_disk_size'")
            __props__['data_node_disk_size'] = data_node_disk_size
            if data_node_disk_type is None:
                raise TypeError("Missing required property 'data_node_disk_type'")
            __props__['data_node_disk_type'] = data_node_disk_type
            if data_node_spec is None:
                raise TypeError("Missing required property 'data_node_spec'")
            __props__['data_node_spec'] = data_node_spec
            __props__['description'] = description
            __props__['instance_charge_type'] = instance_charge_type
            __props__['kibana_whitelists'] = kibana_whitelists
            __props__['kms_encrypted_password'] = kms_encrypted_password
            __props__['kms_encryption_context'] = kms_encryption_context
            __props__['master_node_spec'] = master_node_spec
            __props__['password'] = password
            __props__['period'] = period
            __props__['private_whitelists'] = private_whitelists
            __props__['public_whitelists'] = public_whitelists
            if version is None:
                raise TypeError("Missing required property 'version'")
            __props__['version'] = version
            if vswitch_id is None:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__['vswitch_id'] = vswitch_id
            __props__['zone_count'] = zone_count
            __props__['domain'] = None
            __props__['kibana_domain'] = None
            __props__['kibana_port'] = None
            __props__['port'] = None
            __props__['status'] = None
        super(Instance, __self__).__init__(
            'alicloud:elasticsearch/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, data_node_amount=None, data_node_disk_size=None, data_node_disk_type=None, data_node_spec=None, description=None, domain=None, instance_charge_type=None, kibana_domain=None, kibana_port=None, kibana_whitelists=None, kms_encrypted_password=None, kms_encryption_context=None, master_node_spec=None, password=None, period=None, port=None, private_whitelists=None, public_whitelists=None, status=None, version=None, vswitch_id=None, zone_count=None):
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] data_node_amount: The Elasticsearch cluster's data node quantity, between 2 and 50.
        :param pulumi.Input[float] data_node_disk_size: The single data node storage space.
               - `cloud_ssd`: An SSD disk, supports a maximum of 2048 GiB (2 TB).
               - `cloud_efficiency` An ultra disk, supports a maximum of 5120 GiB (5 TB). If the data to be stored is larger than 2048 GiB, an ultra disk can only support the following data sizes (GiB): [`2560`, `3072`, `3584`, `4096`, `4608`, `5120`].
        :param pulumi.Input[str] data_node_disk_type: The data node disk type. Supported values: cloud_ssd, cloud_efficiency.
        :param pulumi.Input[str] data_node_spec: The data node specifications of the Elasticsearch instance.
        :param pulumi.Input[str] description: The description of instance. It a string of 0 to 30 characters.
        :param pulumi.Input[str] domain: Instance connection domain (only VPC network access supported).
        :param pulumi.Input[str] instance_charge_type: Valid values are `PrePaid`, `PostPaid`, Default to `PostPaid`. From version 1.69.0, the Elasticsearch cluster allows you to update your instance_charge_ype from `PostPaid` to `PrePaid`, the following attributes are required: `period`. But, updating from `PostPaid` to `PrePaid` is not supported.
        :param pulumi.Input[str] kibana_domain: Kibana console domain (Internet access supported).
        :param pulumi.Input[float] kibana_port: Kibana console port.
        :param pulumi.Input[list] kibana_whitelists: Set the Kibana's IP whitelist in internet network.
        :param pulumi.Input[str] kms_encrypted_password: An KMS encrypts password used to a instance. If the `password` is filled in, this field will be ignored, but you have to specify one of `password` and `kms_encrypted_password` fields.
        :param pulumi.Input[dict] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[str] master_node_spec: The dedicated master node spec. If specified, dedicated master node will be created.
        :param pulumi.Input[str] password: The password of the instance. The password can be 8 to 30 characters in length and must contain three of the following conditions: uppercase letters, lowercase letters, numbers, and special characters (`!@#$%^&*()_+-=`).
        :param pulumi.Input[float] period: The duration that you will buy Elasticsearch instance (in month). It is valid when instance_charge_type is `PrePaid`. Valid values: [1~9], 12, 24, 36. Default to 1. From version 1.69.2, when to modify this value, the resource can renewal a `PrePaid` instance.
        :param pulumi.Input[float] port: Instance connection port.
        :param pulumi.Input[list] private_whitelists: Set the instance's IP whitelist in VPC network.
        :param pulumi.Input[str] status: The Elasticsearch instance status. Includes `active`, `activating`, `inactive`. Some operations are denied when status is not `active`.
        :param pulumi.Input[str] version: Elasticsearch version. Supported values: `5.5.3_with_X-Pack`, `6.3_with_X-Pack` and `6.7_with_X-Pack`.
        :param pulumi.Input[str] vswitch_id: The ID of VSwitch.
        :param pulumi.Input[float] zone_count: The Multi-AZ supported for Elasticsearch, between 1 and 3. The `data_node_amount` value must be an integral multiple of the `zone_count` value.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/r/elasticsearch_instance.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["data_node_amount"] = data_node_amount
        __props__["data_node_disk_size"] = data_node_disk_size
        __props__["data_node_disk_type"] = data_node_disk_type
        __props__["data_node_spec"] = data_node_spec
        __props__["description"] = description
        __props__["domain"] = domain
        __props__["instance_charge_type"] = instance_charge_type
        __props__["kibana_domain"] = kibana_domain
        __props__["kibana_port"] = kibana_port
        __props__["kibana_whitelists"] = kibana_whitelists
        __props__["kms_encrypted_password"] = kms_encrypted_password
        __props__["kms_encryption_context"] = kms_encryption_context
        __props__["master_node_spec"] = master_node_spec
        __props__["password"] = password
        __props__["period"] = period
        __props__["port"] = port
        __props__["private_whitelists"] = private_whitelists
        __props__["public_whitelists"] = public_whitelists
        __props__["status"] = status
        __props__["version"] = version
        __props__["vswitch_id"] = vswitch_id
        __props__["zone_count"] = zone_count
        return Instance(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

